Index: trunk/MagicSoft/Mars/manalysis/AnalysisLinkDef.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/AnalysisLinkDef.h	(revision 6914)
+++ trunk/MagicSoft/Mars/manalysis/AnalysisLinkDef.h	(revision 6915)
@@ -20,8 +20,4 @@
 #pragma link C++ class MEventRateCalc+;
 
-#pragma link C++ class MParameterI+;
-#pragma link C++ class MParameterD+;
-#pragma link C++ class MParameterDerr+;
-
 #pragma link C++ class MMcTriggerLvl2+;
 #pragma link C++ class MMcTriggerLvl2Calc+;
Index: trunk/MagicSoft/Mars/manalysis/MParameters.cc
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MParameters.cc	(revision 6914)
+++ 	(revision )
@@ -1,92 +1,0 @@
-/* ======================================================================== *\
-!
-! *
-! * This file is part of MARS, the MAGIC Analysis and Reconstruction
-! * Software. It is distributed to you in the hope that it can be a useful
-! * and timesaving tool in analysing Data of imaging Cerenkov telescopes.
-! * It is distributed WITHOUT ANY WARRANTY.
-! *
-! * Permission to use, copy, modify and distribute this software and its
-! * documentation for any purpose is hereby granted without fee,
-! * provided that the above copyright notice appear in all copies and
-! * that both that copyright notice and this permission notice appear
-! * in supporting documentation. It is provided "as is" without express
-! * or implied warranty.
-! *
-!
-!
-!   Author(s): Thomas Bretz 03/2003 <mailto:tbretz@astro.uni-wuerzburg.de>
-!
-!   Copyright: MAGIC Software Development, 2000-2004
-!
-!
-\* ======================================================================== */
-
-/////////////////////////////////////////////////////////////////////////////
-//
-// MParameterD, MParameterI
-//
-// Storage Container for doubles and ints
-//
-// This classes can be used for intermidiate variables which we don't want
-// to have in a special container.
-//
-/////////////////////////////////////////////////////////////////////////////
-#include "MParameters.h"
-
-#include <fstream>
-
-#include "MLog.h"
-#include "MLogManip.h"
-
-ClassImp(MParameterD);
-ClassImp(MParameterI);
-ClassImp(MParameterDerr);
-//ClassImp(MParameter);
-
-using namespace std;
-
-// --------------------------------------------------------------------------
-//
-// Default constructor.
-//
-MParameterD::MParameterD(const char *name, const char *title)
-{
-    fName  = name  ? name  : "MParameterD";
-    fTitle = title ? title : "Storgare container for general parameters (double)";
-}
-
-// --------------------------------------------------------------------------
-//
-// Default constructor.
-//
-MParameterDerr::MParameterDerr(const char *name, const char *title)
-{
-    fName  = name  ? name  : "MParameterDerr";
-    fTitle = title ? title : "Storgare container for general parameters (double) and its error";
-}
-
-// --------------------------------------------------------------------------
-//
-// Default constructor.
-//
-MParameterI::MParameterI(const char *name, const char *title)
-{
-    fName  = name  ? name  : "MParameterI";
-    fTitle = title ? title : "Storgare container for general parameters (integer)";
-}
-
-void MParameterD::Print(Option_t *o) const
-{
-    *fLog << all << GetDescriptor() << ":  Val=" << fVal << endl;
-}
-
-void MParameterDerr::Print(Option_t *o) const
-{
-    *fLog << all << GetDescriptor() << ":  Val=" << fVal << "  Err=" << fErr << endl;
-}
-
-void MParameterI::Print(Option_t *o) const
-{
-    *fLog << all << GetDescriptor() << ":  Val=" << fVal << endl;
-}
Index: trunk/MagicSoft/Mars/manalysis/MParameters.h
===================================================================
--- trunk/MagicSoft/Mars/manalysis/MParameters.h	(revision 6914)
+++ 	(revision )
@@ -1,120 +1,0 @@
-#ifndef MARS_MParameters
-#define MARS_MParameters
-
-#ifndef MARS_MParContainer
-#include "MParContainer.h"
-#endif
-
-class MParameterD : public MParContainer
-{
-private:
-    Double_t fVal;
-
-public:
-    MParameterD(const char *name=NULL, const char *title=NULL);
-
-    void SetVal(Double_t v) { fVal = v; }
-    Double_t GetVal() const { return fVal; }
-
-    void Print(Option_t *o="") const;
-
-    ClassDef(MParameterD, 1) // Container to hold a generalized parameters (double)
-};
-
-class MParameterDerr : public MParContainer
-{
-private:
-    Double_t fVal;
-    Double_t fErr;
-
-public:
-    MParameterDerr(const char *name=NULL, const char *title=NULL);
-
-    void SetVal(Double_t v, Double_t e) { fVal = v; fErr = e; }
-    Double_t GetVal() const { return fVal; }
-    Double_t GetErr() const { return fErr; }
-
-    void Print(Option_t *o="") const;
-
-    ClassDef(MParameterDerr, 1) // Container to hold a generalized parameters (double) and its Error
-};
-
-class MParameterI : public MParContainer
-{
-private:
-    Int_t fVal;
-
-public:
-    MParameterI(const char *name=NULL, const char *title=NULL);
-
-    void SetVal(Int_t v) { fVal = v; }
-    Int_t GetVal() const { return fVal; }
-
-    void Print(Option_t *o="") const;
-
-    ClassDef(MParameterI, 1) // Container to hold a generalized parameters (integer)
-};
-/*
-class MParameters : public MParContainer
-{
-private:
-    TObjArray fList;
-    TObjArray fNames;
-
-public:
-    MParameters(const char *name=NULL, const char *title=NULL)
-    {
-        fName  = name  ? name  : "MParameters";
-        fTitle = title ? title : "Additional temporary parameters";
-
-        SetReadyToSave();
-    }
-
-    MParamaterI &AddInteger(const TString name, const TString title, Int_t val=0)
-    {
-        MParameterI &p = *new MParameterI(name, title);
-        p.SetValue(val);
-
-        fList.Add(&p);
-
-        TNamed &n = *new TNamed(name, title);
-        fNames.Add(&n);
-
-        return p;
-    }
-
-    MParameterD &AddDouble(const TString name, const TString title, Double_t val=0)
-    {
-        MParameterD &p = *new MParameterD(name, title);
-        p.SetValue(val);
-
-        fList.Add(&p);
-
-        TNamed &n = *new TNamed(name, title);
-        fNames.Add(&n);
-
-        return p;
-    }
-
-    const TObjArray &GetList()
-    {
-        fList.SetNames(&fNames);
-        return fList;
-    }
-
-    MParameterD *GetParameterD(const TString &name)
-    {
-        fList.SetNames(&fNames);
-        return (MParamaterD*)fList.FindObject(name);
-    }
-
-    MParameterI *GetParameterI(const TString &name)
-    {
-        fList.SetNames(&fNames);
-        return (MParameterI*)fList.FindObject(name);
-    }
-
-    ClassDef(MParameters, 1) // List to hold generalized parameters (MParameterD/I)
-    }
-    */
-#endif
Index: trunk/MagicSoft/Mars/manalysis/Makefile
===================================================================
--- trunk/MagicSoft/Mars/manalysis/Makefile	(revision 6914)
+++ trunk/MagicSoft/Mars/manalysis/Makefile	(revision 6915)
@@ -35,5 +35,4 @@
            MEventRate.cc \
            MEventRateCalc.cc \
-           MParameters.cc \
 	   MMcTriggerLvl2.cc \
 	   MMcTriggerLvl2Calc.cc \
Index: trunk/MagicSoft/Mars/mbase/BaseLinkDef.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/BaseLinkDef.h	(revision 6914)
+++ trunk/MagicSoft/Mars/mbase/BaseLinkDef.h	(revision 6915)
@@ -71,4 +71,8 @@
 #pragma link C++ class MArgsEntry+;
 
+#pragma link C++ class MParameterI+;
+#pragma link C++ class MParameterD+;
+#pragma link C++ class MParameterDerr+;
+
 // Tool tasks
 #pragma link C++ class MClone+;
Index: trunk/MagicSoft/Mars/mbase/MParList.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParList.cc	(revision 6914)
+++ trunk/MagicSoft/Mars/mbase/MParList.cc	(revision 6915)
@@ -349,5 +349,6 @@
 
     *fLog << dbginf << warn << "Found object '" << name << "' doesn't ";
-    *fLog << "inherit from " << "'" << classname << "'" << endl;
+    *fLog << "inherit from " << "'" << classname << "' but from '";
+    *fLog << obj->ClassName() << "'" << endl;
     return NULL;
 }
Index: trunk/MagicSoft/Mars/mbase/MParameters.cc
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParameters.cc	(revision 6915)
+++ trunk/MagicSoft/Mars/mbase/MParameters.cc	(revision 6915)
@@ -0,0 +1,96 @@
+/* ======================================================================== *\
+!
+! *
+! * This file is part of MARS, the MAGIC Analysis and Reconstruction
+! * Software. It is distributed to you in the hope that it can be a useful
+! * and timesaving tool in analysing Data of imaging Cerenkov telescopes.
+! * It is distributed WITHOUT ANY WARRANTY.
+! *
+! * Permission to use, copy, modify and distribute this software and its
+! * documentation for any purpose is hereby granted without fee,
+! * provided that the above copyright notice appear in all copies and
+! * that both that copyright notice and this permission notice appear
+! * in supporting documentation. It is provided "as is" without express
+! * or implied warranty.
+! *
+!
+!
+!   Author(s): Thomas Bretz 03/2003 <mailto:tbretz@astro.uni-wuerzburg.de>
+!
+!   Copyright: MAGIC Software Development, 2000-2005
+!
+!
+\* ======================================================================== */
+
+/////////////////////////////////////////////////////////////////////////////
+//
+// MParameterD, MParameterDerr, MParameterI
+//
+// Storage Container for doubles and ints
+//
+// This classes can be used for intermidiate variables which we don't want
+// to have in a special container.
+//
+//
+// MParameterDerr - Version 2:
+//  - inherits from MParemeterD now, where fVal comes from
+//
+/////////////////////////////////////////////////////////////////////////////
+#include "MParameters.h"
+
+#include <fstream>
+
+#include "MLog.h"
+#include "MLogManip.h"
+
+ClassImp(MParameterD);
+ClassImp(MParameterI);
+ClassImp(MParameterDerr);
+//ClassImp(MParameter);
+
+using namespace std;
+
+// --------------------------------------------------------------------------
+//
+// Default constructor.
+//
+MParameterD::MParameterD(const char *name, const char *title)
+{
+    fName  = name  ? name  : "MParameterD";
+    fTitle = title ? title : "Storgare container for general parameters (double)";
+}
+
+// --------------------------------------------------------------------------
+//
+// Default constructor.
+//
+MParameterDerr::MParameterDerr(const char *name, const char *title)
+{
+    fName  = name  ? name  : "MParameterDerr";
+    fTitle = title ? title : "Storgare container for general parameters (double) and its error";
+}
+
+// --------------------------------------------------------------------------
+//
+// Default constructor.
+//
+MParameterI::MParameterI(const char *name, const char *title)
+{
+    fName  = name  ? name  : "MParameterI";
+    fTitle = title ? title : "Storgare container for general parameters (integer)";
+}
+
+void MParameterD::Print(Option_t *o) const
+{
+    *fLog << all << GetDescriptor() << ":  Val=" << fVal << endl;
+}
+
+void MParameterDerr::Print(Option_t *o) const
+{
+    *fLog << all << GetDescriptor() << ":  Val=" << GetVal() << "  Err=" << fErr << endl;
+}
+
+void MParameterI::Print(Option_t *o) const
+{
+    *fLog << all << GetDescriptor() << ":  Val=" << fVal << endl;
+}
Index: trunk/MagicSoft/Mars/mbase/MParameters.h
===================================================================
--- trunk/MagicSoft/Mars/mbase/MParameters.h	(revision 6915)
+++ trunk/MagicSoft/Mars/mbase/MParameters.h	(revision 6915)
@@ -0,0 +1,119 @@
+#ifndef MARS_MParameters
+#define MARS_MParameters
+
+#ifndef MARS_MParContainer
+#include "MParContainer.h"
+#endif
+
+class MParameterD : public MParContainer
+{
+private:
+    Double_t fVal;
+
+public:
+    MParameterD(const char *name=NULL, const char *title=NULL);
+
+    void SetVal(Double_t v) { fVal = v; }
+    Double_t GetVal() const { return fVal; }
+
+    void Print(Option_t *o="") const;
+
+    ClassDef(MParameterD, 1) // Container to hold a generalized parameters (double)
+};
+
+class MParameterDerr : public MParameterD
+{
+private:
+    Double_t fErr;
+
+public:
+    MParameterDerr(const char *name=NULL, const char *title=NULL);
+
+    void SetVal(Double_t v)             { MParameterD::SetVal(v); }
+    void SetVal(Double_t v, Double_t e) { SetVal(v); fErr = e; }
+    Double_t GetErr() const { return fErr; }
+
+    void Print(Option_t *o="") const;
+
+    ClassDef(MParameterDerr, 2) // Container to hold a generalized parameters (double) and its Error
+};
+
+class MParameterI : public MParContainer
+{
+private:
+    Int_t fVal;
+
+public:
+    MParameterI(const char *name=NULL, const char *title=NULL);
+
+    void SetVal(Int_t v) { fVal = v; }
+    Int_t GetVal() const { return fVal; }
+
+    void Print(Option_t *o="") const;
+
+    ClassDef(MParameterI, 1) // Container to hold a generalized parameters (integer)
+};
+/*
+class MParameters : public MParContainer
+{
+private:
+    TObjArray fList;
+    TObjArray fNames;
+
+public:
+    MParameters(const char *name=NULL, const char *title=NULL)
+    {
+        fName  = name  ? name  : "MParameters";
+        fTitle = title ? title : "Additional temporary parameters";
+
+        SetReadyToSave();
+    }
+
+    MParamaterI &AddInteger(const TString name, const TString title, Int_t val=0)
+    {
+        MParameterI &p = *new MParameterI(name, title);
+        p.SetValue(val);
+
+        fList.Add(&p);
+
+        TNamed &n = *new TNamed(name, title);
+        fNames.Add(&n);
+
+        return p;
+    }
+
+    MParameterD &AddDouble(const TString name, const TString title, Double_t val=0)
+    {
+        MParameterD &p = *new MParameterD(name, title);
+        p.SetValue(val);
+
+        fList.Add(&p);
+
+        TNamed &n = *new TNamed(name, title);
+        fNames.Add(&n);
+
+        return p;
+    }
+
+    const TObjArray &GetList()
+    {
+        fList.SetNames(&fNames);
+        return fList;
+    }
+
+    MParameterD *GetParameterD(const TString &name)
+    {
+        fList.SetNames(&fNames);
+        return (MParamaterD*)fList.FindObject(name);
+    }
+
+    MParameterI *GetParameterI(const TString &name)
+    {
+        fList.SetNames(&fNames);
+        return (MParameterI*)fList.FindObject(name);
+    }
+
+    ClassDef(MParameters, 1) // List to hold generalized parameters (MParameterD/I)
+    }
+    */
+#endif
Index: trunk/MagicSoft/Mars/mbase/Makefile
===================================================================
--- trunk/MagicSoft/Mars/mbase/Makefile	(revision 6914)
+++ trunk/MagicSoft/Mars/mbase/Makefile	(revision 6915)
@@ -49,4 +49,5 @@
            MStatusArray.cc \
            MStatusDisplay.cc \
+           MParameters.cc \
 	   MArray.cc \
 	   MArrayB.cc \
Index: trunk/MagicSoft/Mars/mhbase/HBaseLinkDef.h
===================================================================
--- trunk/MagicSoft/Mars/mhbase/HBaseLinkDef.h	(revision 6914)
+++ trunk/MagicSoft/Mars/mhbase/HBaseLinkDef.h	(revision 6915)
@@ -13,5 +13,4 @@
 
 #pragma link C++ class MBinning+;
-#pragma link C++ class MWeight+;
 
 #endif
Index: trunk/MagicSoft/Mars/mhbase/MFillH.h
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MFillH.h	(revision 6914)
+++ trunk/MagicSoft/Mars/mhbase/MFillH.h	(revision 6915)
@@ -9,5 +9,5 @@
 class MMap;
 class MData;
-class MWeight;
+class MParameterD;
 class MParList;
 
@@ -30,5 +30,5 @@
     TString fNameTab;
 
-    MWeight *fWeight;             // Pointer to the container storing a weight
+    MParameterD *fWeight;         // Pointer to the container storing a weight
     TString fWeightName;          // Name of a container storing a weight
 
@@ -62,5 +62,5 @@
     void SetRuleForIdx(MData *rule);
 
-    void SetWeight(MWeight *w)       { fWeight = w; }
+    void SetWeight(MParameterD *w)   { fWeight = w; }
     void SetWeight(const char *name) { fWeightName = name; }
 
Index: trunk/MagicSoft/Mars/mhbase/MWeight.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MWeight.cc	(revision 6914)
+++ 	(revision )
@@ -1,35 +1,0 @@
-/* ======================================================================== *\
-!
-! *
-! * This file is part of MARS, the MAGIC Analysis and Reconstruction
-! * Software. It is distributed to you in the hope that it can be a useful
-! * and timesaving tool in analysing Data of imaging Cerenkov telescopes.
-! * It is distributed WITHOUT ANY WARRANTY.
-! *
-! * Permission to use, copy, modify and distribute this software and its
-! * documentation for any purpose is hereby granted without fee,
-! * provided that the above copyright notice appear in all copies and
-! * that both that copyright notice and this permission notice appear
-! * in supporting documentation. It is provided "as is" without express
-! * or implied warranty.
-! *
-!
-!
-!   Author(s): Thomas Bretz  04/2003 <mailto:tbretz@astro.uni-wuerzburg.de>
-!
-!   Copyright: MAGIC Software Development, 2000-2003
-!
-!
-\* ======================================================================== */
-
-/////////////////////////////////////////////////////////////////////////////
-//
-//   MWeight
-//
-//   Storage container for a weight to fill histograms
-//
-/////////////////////////////////////////////////////////////////////////////
-#include "MWeight.h"
-
-ClassImp(MWeight);
-
Index: trunk/MagicSoft/Mars/mhbase/MWeight.h
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MWeight.h	(revision 6914)
+++ 	(revision )
@@ -1,32 +1,0 @@
-#ifndef MARS_MWeight
-#define MARS_MWeight
-
-/////////////////////////////////////////////////////////////////////////////
-//                                                                         //
-//  MWeight                                                                //
-//                                                                         //
-/////////////////////////////////////////////////////////////////////////////
-
-#ifndef MARS_MParContainer
-#include "MParContainer.h"
-#endif
-
-class MWeight : public MParContainer
-{
-private:
-    Double_t fWeight;
-
-public:
-    MWeight(const char *name=NULL, const char *title=NULL) : fWeight(1)
-    {
-        fName  = name  ? name  : "MWeight";
-        fTitle = title ? title : "A weight for filling histograms";
-    }
-
-    void SetWeight(Double_t weight) { fWeight = weight; }
-    Double_t GetWeight() const { return fWeight; }
-
-    ClassDef(MWeight, 1) // A weight for filling histograms
-};
-
-#endif
Index: trunk/MagicSoft/Mars/mhbase/Makefile
===================================================================
--- trunk/MagicSoft/Mars/mhbase/Makefile	(revision 6914)
+++ trunk/MagicSoft/Mars/mhbase/Makefile	(revision 6915)
@@ -23,5 +23,4 @@
 SRCFILES = MFillH.cc \
            MBinning.cc \
-           MWeight.cc \
            MH.cc \
            MH3.cc \
Index: trunk/MagicSoft/Mars/mjobs/MJStar.cc
===================================================================
--- trunk/MagicSoft/Mars/mjobs/MJStar.cc	(revision 6914)
+++ trunk/MagicSoft/Mars/mjobs/MJStar.cc	(revision 6915)
@@ -229,5 +229,5 @@
 
     MHVsTime hvs("MEventRate.fRate");
-    hvs.SetTitle("Rate per 500 events;R [Hz];Counts");
+    hvs.SetTitle("Rate per 500 events;;R [Hz]");
     hvs.SetNumEvents(500);
 
Index: trunk/MagicSoft/Mars/mmontecarlo/MMcWeightEnergySpecCalc.cc
===================================================================
--- trunk/MagicSoft/Mars/mmontecarlo/MMcWeightEnergySpecCalc.cc	(revision 6914)
+++ trunk/MagicSoft/Mars/mmontecarlo/MMcWeightEnergySpecCalc.cc	(revision 6915)
@@ -82,5 +82,5 @@
 //                                            
 //  Output Container:                        
-//   MWeight  
+//   MWeight [MParameterD]
 //
 //////////////////////////////////////////////////////////////////////////////
@@ -94,5 +94,5 @@
 #include "MMcRunHeader.hxx"
 #include "MMcCorsikaRunHeader.h"
-#include "MWeight.h"
+#include "MParameters.h"
 
 #include "TF1.h"
@@ -232,10 +232,7 @@
       }
 
-    fWeight = (MWeight*)pList->FindCreateObj("MWeight");
+    fWeight = (MParameterD*)pList->FindCreateObj("MParameterD", "MWeight");
     if (!fWeight)
-      {
-	*fLog << err << dbginf << "MWeight not found... exit." << endl;
 	return kFALSE;
-      }
     
     return kTRUE;
@@ -347,14 +344,14 @@
 
     const Double_t C = fCorSpecInt / fNewSpecInt;
-    Double_t weight;
+    Double_t weight = C;
 
 
     if (fNewSpecIsPowLaw)   
-      weight = C * pow(energy,fNewSlope-fCorsikaSlope);
+        weight *= pow(energy,fNewSlope-fCorsikaSlope);
     else
-      weight = C * fNewSpectrum->Eval(energy) / pow(energy,fCorsikaSlope);
+        weight *= fNewSpectrum->Eval(energy) / pow(energy,fCorsikaSlope);
      
 
-    fWeight->SetWeight( weight );
+    fWeight->SetVal(weight);
 
     return kTRUE;
Index: trunk/MagicSoft/Mars/mmontecarlo/MMcWeightEnergySpecCalc.h
===================================================================
--- trunk/MagicSoft/Mars/mmontecarlo/MMcWeightEnergySpecCalc.h	(revision 6914)
+++ trunk/MagicSoft/Mars/mmontecarlo/MMcWeightEnergySpecCalc.h	(revision 6915)
@@ -9,5 +9,5 @@
 class MParList;
 class MMcEvt;
-class MWeight;
+class MParameterD;
 class TF1;
 
@@ -19,5 +19,5 @@
 
     const MMcEvt *fMcEvt;
-    MWeight  *fWeight;
+    MParameterD  *fWeight;
 
     TF1*     fNewSpectrum;     // Function with the new spectrum

Index: trunk/MagicSoft/Mars/mhbase/MFillH.cc
===================================================================
--- trunk/MagicSoft/Mars/mhbase/MFillH.cc	(revision 6914)
+++ trunk/MagicSoft/Mars/mhbase/MFillH.cc	(revision 6915)
@@ -51,5 +51,5 @@
 //
 // To use a weight for each event filled in a histogram call
 // SetWeight(). You can eithe use the name of a MWeight container stored
 // in the parameter list or a pointer to it as an argument.
 //
@@ -92,5 +92,5 @@
 #include "MHArray.h"
 
-#include "MWeight.h"
+#include "MParameters.h"
 
 #include "MParList.h"
@@ -424,9 +424,9 @@
     if (!fWeight && !fWeightName.IsNull())
     {
-        fWeight = (MWeight*)pList->FindObject(fWeightName, "MWeight");
+        fWeight = (MParameterD*)pList->FindObject(fWeightName, "MParameterD");
 
 	if (!fWeight)
         {
-            *fLog << err << fWeightName << " [MWeight] not found... aborting." << endl;
+            *fLog << err << fWeightName << " [MParameterD] not found... aborting." << endl;
             return kFALSE;
         }
@@ -547,10 +547,9 @@
         fCanvas->cd();
 
-    const Bool_t rc = fH->Fill(fParContainer, fWeight?fWeight->GetWeight():1);
+    const Bool_t rc = fH->Fill(fParContainer, fWeight?fWeight->GetVal():1);
     fH->SetNumExecutions(GetNumExecutions()+1);
 
     if (save && fCanvas)
         save->cd();
-
     return rc;
 } 
@@ -51,5 +51,5 @@
 //
 // To use a weight for each event filled in a histogram call
-// SetWeight(). You can eithe use the name of a MWeight container stored
+// SetWeight(). You can eithe use the name of a MParameterD container stored
 // in the parameter list or a pointer to it as an argument.
 //